==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_TW\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  ""

]
, "Groups"
: "群組"

, "Roles"
: "角色"

, "Applications"
: "應用程式"

, "Containers"
: ""

, "Shared Tags"
: "分享標記"

, "Customfields"
: ""

, "Computers"
: ""

, "Access Log, Access Logs"
: [
  ""

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "管理者"

, "Refresh"
: ""

, "Name"
: "名字"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  ""

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  ""

]
, "Application, Applications"
: [
  ""

]
, "Config, Configs"
: [
  ""

]
, "Configs"
: ""

, "Please wait"
: "請稍後"

, "Updating Memberships"
: "更新會員資料"

, "Failed"
: "失敗"

, "Could not save group."
: "無法儲存群組"

, "Errors"
: "錯誤"

, "Please fix the errors noted."
: ""

, "Group Name"
: "群組名稱"

, "Description"
: "描述"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Group Members"
: "群組成員"

, "Transferring {0}..."
: ""

, "Add new group"
: "加入新群組"

, "Edit Group \"{0}\""
: "修改群組 \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "enable application"
: "啟用應用程式"

, "disable application"
: "關閉應用程式"

, "settings"
: "設定"

, "Search:"
: "尋找:"

, "disabled"
: "關閉"

, "enabled"
: "啟用"

, "unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: "無此應用程式顯示"

, "Order"
: ""

, "Status"
: "狀態"

, "Version"
: ""

, "Confirm"
: "再確認"

, "Do you really want to delete the selected groups?"
: "確認刪除已選的群組嗎?"

, "Deleting group(s)..."
: "正在刪除群組..."

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Displaying groups {0} - {1} of {2}"

, "No groups to display"
: "無此群組"

, "ID"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: ""

, "IP Address"
: "IP 位址"

, "Login Time"
: "登入時間"

, "Logout Time"
: "登出時間"

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: "登入帳號"

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "密碼無效"

, "ambiguous username"
: ""

, "user not found"
: "無此帳號"

, "failure"
: "失敗"

, "success"
: "成功"

, "Could not save role."
: "無法儲存角色"

, "Deleting role..."
: "正在刪除角色..."

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: "權限"

, "Members"
: "成員"

, "Role Name"
: "角色名稱"

, "Role"
: ""

, "Add New Role"
: "加入新角色"

, "Edit Role \"{0}\""
: "編輯角色 \"{0}\""

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Color"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: "確認刪除已選的角色嗎?"

, "Deleting role(s)..."
: "正在刪除角色..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: "無此角色"

, "Do you really want to delete the selected tags?"
: "確認刪除已選的標籤嗎?"

, "Deleting tag(s)..."
: "正在刪除標籤..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: "無此標記顯示"

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "姓氏"

, "First name"
: "名字"

, "Email"
: "電子郵件"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: "最後登入於"

, "Last login from"
: "最後登入從"

, "Password changed"
: "變更密碼"

, "Expires"
: "過期"

, "Set new password"
: "設定新密碼"

, "Please enter the new password:"
: "請輸入新密碼"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "主要群組"

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Logon Time"
: ""

, "never logged in"
: "從未登入過"

, "Home Path"
: ""

, "Logoff Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: "從不"

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: ""

, "Add a forward address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "Password"
: "密碼"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: "設定密碼"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: "內容"

, "Account Rights"
: "帳號權限"

, "View"
: "檢視"

, "Use"
: ""

, "Tag Name"
: "標籤名稱"

, "Tag"
: ""

, "Add New Tag"
: "加入新標籤"

, "Edit Tag \"{0}\""
: "編輯標籤 \"{0}\""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "管理存取紀錄"

, "delete access log entries"
: "清空紀錄檔"

, "manage accounts"
: "帳號管理"

, "add and edit users and groups, add group members, change user passwords"
: "編修帳號, 群組, 群組成員, 變更使用者密碼"

, "manage applications"
: "應用程式管理"

, "enable and disable applications, edit application settings"
: "啟用或關閉應用程式或編輯設定"

, "manage roles"
: "角色管理"

, "add and edit roles, add new members to roles, add application rights to roles"
: "新增編輯角色, 加入成員或新增應用程式權限給角色"

, "manage shared tags"
: "標籤(tags)分享管理"

, "add, delete and edit shared tags"
: "新增, 修改, 刪除標籤(tags)分享"

, "manage computers"
: ""

, "add, delete and edit (samba) computers"
: ""

, "manage containers"
: ""

, "add, delete and edit containers and manage container grants"
: ""

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "檢視紀錄檔"

, "view access log list"
: "檢視紀錄檔列表"

, "view accounts"
: "檢視帳號"

, "view accounts list and details"
: "檢視帳號列表和明細"

, "view applications"
: "檢視應用程式"

, "view applications list and details"
: "檢視應用程式列表和明細"

, "view roles"
: "檢視角色"

, "view roles list and details"
: "檢視角色列表和明細"

, "view computers"
: ""

, "view computers list and details"
: ""

, "view containers"
: ""

, "view personal and shared containers"
: ""

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: ""

, "Access Log"
: ""

, "Computer"
: ""

, "Group"
: ""

, "Application"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Samba User"
: ""

, "Email User"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "Search:"
: "尋找:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: "無此應用程式顯示"

, "Order"
: ""

, "Name"
: "名字"

, "Status"
: "狀態"

, "Version"
: ""

, "Confirm"
: "再確認"

, "Do you really want to delete the selected groups?"
: "確認刪除已選的群組嗎?"

, "Deleting group(s)..."
: "正在刪除群組..."

, "Failed"
: "失敗"

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Displaying groups {0} - {1} of {2}"

, "No groups to display"
: "無此群組"

, "ID"
: ""

, "E-mail"
: ""

, "Description"
: "描述"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "錯誤"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "請稍後"

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: ""

, "Allowed Contexts"
: ""

, "Context"
: "內容"

, "Account Rights"
: "帳號權限"

, "View"
: "檢視"

, "Use"
: ""

, "Tag Name"
: "標籤名稱"

, "Color"
: ""

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: "加入新標籤"

, "Edit Tag \"{0}\""
: "編輯標籤 \"{0}\""

, "Do you really want to delete the selected tags?"
: "確認刪除已選的標籤嗎?"

, "Deleting tag(s)..."
: "正在刪除標籤..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: "無此標記顯示"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "更新會員資料"

, "Could not save role."
: "無法儲存角色"

, "Deleting role..."
: "正在刪除角色..."

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: "權限"

, "Members"
: "成員"

, "Role Name"
: "角色名稱"

, "Role"
: ""

, "Add New Role"
: "加入新角色"

, "Edit Role \"{0}\""
: "編輯角色 \"{0}\""

, "Do you really want to delete the selected roles?"
: "確認刪除已選的角色嗎?"

, "Deleting role(s)..."
: "正在刪除角色..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: "無此角色"

, "Access Log, Access Logs"
: [
  ""

]
, "Groups"
: "群組"

, "Applications"
: "應用程式"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "主要群組"

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: "登入時間"

, "never logged in"
: "從未登入過"

, "Home Path"
: ""

, "Logout Time"
: "登出時間"

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: "從不"

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "First name"
: "名字"

, "Last name"
: "姓氏"

, "Login name"
: ""

, "Password"
: "密碼"

, "OpenID"
: ""

, "enabled"
: "啟用"

, "disabled"
: "關閉"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "過期"

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: "最後登入於"

, "don't know"
: ""

, "Last login from"
: "最後登入從"

, "Password set"
: "設定密碼"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  ""

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "變更密碼"

, "Set new password"
: "設定新密碼"

, "Please enter the new password:"
: "請輸入新密碼"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "群組名稱"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "群組成員"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  ""

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "角色"

, "Containers"
: ""

, "Shared Tags"
: "分享標記"

, "Customfields"
: ""

, "Computers"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "管理者"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP 位址"

, "Client Type"
: ""

, "Session ID"
: ""

, "Login Name"
: "登入帳號"

, "Result"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "密碼無效"

, "ambiguous username"
: ""

, "user not found"
: "無此帳號"

, "failure"
: "失敗"

, "success"
: "成功"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""


























, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: ""

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: ""

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
